# Copyright (c) 2013, University of Bristol and University of Southampton.

from EStat.Templating import Template

class TemplateMissingIndicator(Template):
    'Creates a new column indicating which rows of user-nominated variable are missing. User chooses whether 0 or 1 indicates missing and name of new variable.'

    __version__ = '1.0.0'

    tags = ['Data manipulation']
    engines = ['Python_script']

    inputs = '''
variable_with_missing = DataVector('Variable with missing data: ')
missing_dummy = Text('Name of new variable with missing data indicator: ')
yes_if_one_missing = Boolean('In the resulting 0/1 variable, do you want 1 to indicate missing? ')
new_dataset = Text('Name of output dataset: ')
'''

    pythonscript = '''
import numpy

import EStat
from EStat.Templating import *
from EStat.DTAFile import DTAFile

retval = DTAFile()

retval.nobs = datafile.nobs
for k in datafile.variables.keys():
    retval.addvariable(k, data = datafile.variables[k]['data'])

missing_indicator = numpy.array(numpy.ma.getmaskarray(datafile.variables[str(variable_with_missing)]['data']), dtype=int)
if not yes_if_one_missing:
    missing_indicator = 1 - missing_indicator

retval.addvariable(str(missing_dummy), data = missing_indicator)
outputs[str(new_dataset)] = retval
'''
